@@ -20,7 +20,7 @@ class PyBambooHR(object):
     and an optional datatype argument (defaults to JSON). This class implements
     methods for basic CRUD operations for employees and more.
     """
-    def __init__(self, api_key='', subdomain='', datatype='JSON', underscore_keys=False):
+    def __init__(self, subdomain='', api_key='', datatype='JSON', underscore_keys=False):
         """
         Using the subdomain, __init__ initializes the base_url for our API calls.
         This method also sets up some headers for our HTTP requests as well as our authentication (API key).
@@ -199,6 +199,8 @@ class PyBambooHR(object):
         xml = self._format_employee_xml(employee)
         url = self.base_url + 'employees/'
         r = requests.post(url, data=xml, headers=self.headers, auth=(self.api_key, ''))
+        r.raise_for_status()
+
         return {'url': r.headers['location'], 'id': r.headers['location'].replace(url, "")}
 
     def update_employee(self, id, employee):
@@ -214,8 +216,9 @@ class PyBambooHR(object):
         xml = self._format_employee_xml(employee)
         url = self.base_url + 'employees/{0}'.format(id)
         r = requests.post(url, data=xml, headers=self.headers, auth=(self.api_key, ''))
-        return_value = r.status_code == 200
-        return return_value
+        r.raise_for_status()
+
+        return True
 
     def get_employee_directory(self):
         """
@@ -226,6 +229,8 @@ class PyBambooHR(object):
         """
         url = self.base_url + 'employees/directory'
         r = requests.get(url, headers=self.headers, auth=(self.api_key, ''))
+        r.raise_for_status()
+
         data = r.json()
         employees = data['employees']
         if self.underscore_keys:
@@ -262,6 +267,8 @@ class PyBambooHR(object):
 
         url = self.base_url + "employees/{0}".format(employee_id)
         r = requests.get(url, headers=self.headers, params=payload, auth=(self.api_key, ''))
+        r.raise_for_status()
+
         employee = r.json()
 
         if self.underscore_keys:
@@ -289,6 +296,7 @@ class PyBambooHR(object):
         filter_duplicates = 'yes' if filter_duplicates else 'no'
         url = self.base_url + "reports/{0}?format={1}&fd={2}".format(report_id, report_format, filter_duplicates)
         r = requests.get(url, headers=self.headers, auth=(self.api_key, ''))
+        r.raise_for_status()
 
         if report_format == 'json':
             # return list/dict for json type
@@ -343,9 +351,12 @@ class PyBambooHR(object):
         xml = self._format_report_xml(get_fields, title=title, report_format=report_format)
         url = self.base_url + "reports/custom/?format={0}".format(report_format)
         r = requests.post(url, data=xml, headers=self.headers, auth=(self.api_key, ''))
+        r.raise_for_status()
 
-
-        if report_format in ('csv', 'xml'):
+        if report_format == 'json':
+            # return list/dict for json type
+            result = r.json()
+        elif report_format in ('csv', 'xml'):
             # return text for csv type
             result = r.text
         else:
